summaryrefslogtreecommitdiffstats
path: root/chrome/browser/automation/automation_provider.h
diff options
context:
space:
mode:
authorvandebo@chromium.org <vandebo@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-11 22:41:43 +0000
committervandebo@chromium.org <vandebo@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-07-11 22:41:43 +0000
commitf6ff0dfd962666d79e4919e23c0078283fed2922 (patch)
tree88a7462b11dc1463ef7cc728ccabaf7012cb188d /chrome/browser/automation/automation_provider.h
parentb3839a6adf2c4ec9572852577b2c270b9266820a (diff)
downloadchromium_src-f6ff0dfd962666d79e4919e23c0078283fed2922.zip
chromium_src-f6ff0dfd962666d79e4919e23c0078283fed2922.tar.gz
chromium_src-f6ff0dfd962666d79e4919e23c0078283fed2922.tar.bz2
Revert 52054: causing startup tests to fail on Vista and XP perf dbg
Revert 52054 - Refactor json automation interface for pyauto hooks. Reduces the number of lines you need to add per new automation hook. Shaves off several lines of code. Refactor pyauto.py to obviate raising exception in case the json interfaces produces an error string. Review URL: http://codereview.chromium.org/2898001 TBR=nirnimesh@chromium.org Review URL: http://codereview.chromium.org/2977001 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@52067 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/automation/automation_provider.h')
-rw-r--r--chrome/browser/automation/automation_provider.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/automation/automation_provider.h b/chrome/browser/automation/automation_provider.h
index 0598179..d8e8d0b 100644
--- a/chrome/browser/automation/automation_provider.h
+++ b/chrome/browser/automation/automation_provider.h
@@ -463,11 +463,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// data structure used in the browser.
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
// err_mesg: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(
- const ListValue& profiles, std::string* err_mesg);
+ const ListValue& profiles, std::string* json_return);
static std::vector<CreditCard> GetCreditCardsFromList(
- const ListValue& cards, std::string* err_mesg);
+ const ListValue& cards, std::string* json_return);
// The opposite of the above: translates from the internal data structure
// for profiles and credit cards to a ListValue of DictionaryValues. The
@@ -463,11 +463,11 @@ class AutomationProvider : public base::RefCounted<AutomationProvider>,
// Args:
// profiles/cards: the ListValue of profiles/credit cards to translate.
- // err_mesg: a pointer to the return string in case of error.
+ // json_return: a pointer to the return string in case of error.
static std::vector<AutoFillProfile> GetAutoFillProfilesFromList(